@@ -5,7 +5,7 @@ use warnings;
 use vars qw($VERSION);
 use LWP::UserAgent;
 
-$VERSION = '1.7';
+$VERSION = '1.8';
 
 sub new
 {
@@ -26,12 +26,10 @@ sub get
 
     return unless defined $domain;
 
-    my $res = $self->{ua}->get("http://www.alexa.com/siteinfo/$domain");
+    my $res = $self->{ua}->get("http://xml.alexa.com/data?cli=10&dat=nsa&url=$domain");
     return $res->status_line if !$res->is_success;
 
-    my $cont = $res->content; $cont =~ s/[\r\n]//g;
-
-    my ($updown, $rank) = $cont =~ /<div class="data (up|down|steady)"><img.*?\/>\s?([\d,]+)/i;
+    my ($rank) = $res->content =~ /<POPULARITY URL=".+" TEXT="(\d+)"/;
 
     return $rank;
 }
@@ -47,19 +45,18 @@ sub get_country_rank
     my $res = $self->{ua}->get("http://www.alexa.com/siteinfo/$par->{Domain}");
     return $res->status_line if !$res->is_success;
 
-    my $cont = $res->content; $cont =~ s/[\r\n]//g;
+    my $cont = $res->content;
 
     return 0 unless $cont =~ /<div class="content1" id="traffic-rank-by-country">(.+?)<div class="content1" id="where-visitors-go"/gs;
   
     my $listdata = $1;
 
-    while ( $listdata =~ /<div class="tr1.*?">(.+?)<\/div>/igs ) {
-        my $item = $1;
-
-        if ( $item =~ /$par->{Country}/gs ) {
-
-            $item =~ /<p class="tc1" style=".*?">([\d,]+)/i;
+    while ($listdata =~ /<div class="tr1.*?">(.+?)<\/div>/igs) {
+        my $item = $1; $item =~ s/,//g;
 
+        if ($item =~ /$par->{Country}/gs) {
+            $item =~ /<p class="tc1" style=".*?">(\d+)/i;
+            
             return $1;
         }
     }
@@ -81,8 +78,8 @@ use WWW::Alexa::TrafficRank;
  
 my $tr = WWW::Alexa::TrafficRank->new();
  
-my $rank = $tr->get('guruperl.net');
-my $country_rank = $tr->get_country_rank(Domain => 'guruperl.net', Country => 'United States');
+my $rank = $tr->get('filedir.com');
+my $country_rank = $tr->get_country_rank(Domain => 'filedir.com', Country => 'United States');
  
 print $rank, "\n", $country_rank;
 
@@ -122,13 +119,13 @@ specified poxy. C<proxy> is the host which serve requests to Alexa.
 
 =over 4
 
-=item  $rank = $tr->get('guruperl.net');
+=item  $rank = $tr->get('filedir.com');
 
 Queries Alexa for a specified traffic rank URL and returns traffic rank
 text value. If query fails for some reason (Alexa unreachable, undefined 
 url passed) it return error string.
 
-=item  $country_rank = $tr->get_country_rank(Domain => 'guruperl.net', Country => 'United States');
+=item  $country_rank = $tr->get_country_rank(Domain => 'filedir.com', Country => 'United States');
 
 Extract the rank in the country. If we get a match on the country name in 
 the item then extract the ranking value and return. The country name must match the name 
@@ -142,16 +139,14 @@ If you find any, please report ;)
 
 =head1 AUTHOR
 
-Guruperl.net
-  F<E<lt>root@guruperl.netE<gt>>.
+Alex Zhdanau
+  F<E<lt>guruperl@cpan.orgE<gt>>.
   
-  http://getabest.com/ - Software Downloads
+  http://FileDir.com - All of your downloads in one place.
   
-  http://guruperl.net/ - Professional Scripts
-
 =head1 COPYRIGHT
 
-Copyright 2010, Guruperl.net, All Rights Reserved.
+Copyright 2013, Alex Zhdanau, All Rights Reserved.
 
 You may use, modify, and distribute this package under the
 same terms as Perl itself.
